@@ -7,7 +7,7 @@ Config_path = Path() / "data" / "arcaea" / "config.yml"
 New_map = {
     "aua_url": "URL",
     "aua_ua": "SECRET",
-    "src_url": "http://api.ritsuki.top/api/",
+    "src_url": "https://api.ritsuki.top/api/",
 }
 
 
@@ -44,5 +44,3 @@ class ConfigsManager:
 
 
 config = ConfigsManager(Config_path)
-
-# print(Config.get_config("aua_ua", "SECRET"))
