@@ -16,9 +16,9 @@ async def assets_update_handler(event: MessageEvent, arg: Message = CommandArg()
             if args[1] == "--purge":
                 if path.exists(assets_root / "song"):
                     rmtree(assets_root / "song")
-                if path.exists(assets_root / "song"):
-                    rmtree(assets_root / "song")
-                await arc.send("正在更新，请关注控制台更新进度…")
+                if path.exists(assets_root / "char"):
+                    rmtree(assets_root / "char")
+        await arc.send("正在更新，请关注控制台更新进度…")
 
         result_song = await check_song_update()
         result_char = await check_char_update()
